@@ -134,7 +134,7 @@ static int syscall_32_to_64[]={
     __NR_swapon,	/* 87 */
     __NR_reboot,	/* 88 */
     -1, /* readdir,	 89 */
-    __NR_mmap,		/* 90 */
+    SYS_mmap2,		/* 90 */ /* See comment for __NR_mmap (192) */
     __NR_munmap,	/* 91 */
     __NR_truncate,	/* 92 */
     __NR_ftruncate,	/* 93 */
@@ -236,7 +236,8 @@ static int syscall_32_to_64[]={
     __NR_putpmsg,		/* 189 */	/* some people actually want streams */
     __NR_vfork,		        /* 190 */
     -1, /* ugetrlimit,		191 */	/* SuS compliant getrlimit */
-    SYS_mmap2,		        /* 192 */
+    __NR_mmap,                  /* 192 */
+    /* Technically, this is mmap2. However, it is much more reasonable as far as arguments are handled to map it this way. */
     -1, /* truncate64,		 193 */
     -1, /* ftruncate64,		 194 */
     SYS_stat64,		/* 195 */
@@ -452,7 +453,7 @@ void *ptlib_get_pc( pid_t pid )
     return (void *)ptrace( PTRACE_PEEKUSER, pid, RIP, 0 );
 }
 
-int ptlib_set_pc( pid_t pid, void *location )
+int ptlib_set_pc( pid_t pid, int_ptr location )
 {
     return ptrace( PTRACE_POKEUSER, pid, RIP, location );
 }
@@ -505,7 +506,7 @@ int ptlib_set_syscall( pid_t pid, int sc_num )
     return ptrace(PTRACE_POKEUSER, pid, ORIG_RAX, sc_num);
 }
 
-int ptlib_generate_syscall( pid_t pid, int sc_num, void *base_memory )
+int ptlib_generate_syscall( pid_t pid, int sc_num, int_ptr base_memory )
 {
     sc_num=translate_syscall( pid, sc_num );
 
@@ -605,22 +606,22 @@ int ptlib_get_error( pid_t pid, int sc_num )
     return -(long)ptlib_get_retval( pid );
 }
 
-int ptlib_get_mem( pid_t pid, void *process_ptr, void *local_ptr, size_t len )
+int ptlib_get_mem( pid_t pid, int_ptr process_ptr, void *local_ptr, size_t len )
 {
     return ptlib_linux_get_mem( pid, process_ptr, local_ptr, len );
 }
 
-int ptlib_set_mem( pid_t pid, const void *local_ptr, void *process_ptr, size_t len )
+int ptlib_set_mem( pid_t pid, const void *local_ptr, int_ptr process_ptr, size_t len )
 {
     return ptlib_linux_set_mem( pid, local_ptr, process_ptr, len );
 }
 
-int ptlib_get_string( pid_t pid, void *process_ptr, char *local_ptr, size_t maxlen )
+int ptlib_get_string( pid_t pid, int_ptr process_ptr, char *local_ptr, size_t maxlen )
 {
     return ptlib_linux_get_string( pid, process_ptr, local_ptr, maxlen );
 }
 
-int ptlib_set_string( pid_t pid, const char *local_ptr, void *process_ptr )
+int ptlib_set_string( pid_t pid, const char *local_ptr, int_ptr process_ptr )
 {
     return ptlib_linux_set_string( pid, local_ptr, process_ptr );
 }
@@ -660,7 +661,7 @@ pid_t ptlib_get_parent( pid_t pid )
     return ptlib_linux_get_parent(pid);
 }
 
-int ptlib_fork_enter( pid_t pid, int orig_sc, void *process_mem, void *our_mem, void *registers[PTLIB_STATE_SIZE],
+int ptlib_fork_enter( pid_t pid, int orig_sc, int_ptr process_mem, void *our_mem, void *registers[PTLIB_STATE_SIZE],
         int_ptr context[FORK_CONTEXT_SIZE] )
 {
     return ptlib_linux_fork_enter( pid, orig_sc, process_mem, our_mem, registers, context );
