@@ -3,21 +3,25 @@
 
 #include <sys/time.h>
 #include <sys/resource.h>
+#include <sys/mman.h>
 
 #include <list>
+#include <set>
 
 #include <stdio.h>
 #include <string>
+#include <assert.h>
 
 #include "arch/platform.h"
 #include "platform_specific.h"
 
-#include "shared_mem.h"
+#include "refcount.h"
 
 extern size_t static_mem_size, shared_mem_size;
 
-bool attach_debugger( pid_t child, int socket );
-int process_children( int master_socket );
+bool attach_debugger( pid_t child );
+class daemonProcess;
+int process_children( daemonProcess *daemon );
 int process_sigchld( pid_t pid, enum PTLIB_WAIT_RET wait_state, int status, long ret );
 
 // Called whenever a new process is created
@@ -74,9 +78,65 @@ struct pid_state {
     } state;
     int orig_sc; // Original system call
 
-    void *memory; // Where and how much mem do we have inside the process's address space
-    void *shared_memory; // Process address of shared memory
-    shared_mem shared_mem_local; // local pointers to the shared memory
+    class process_memory {
+        int_ptr memory; // Where and how much mem do we have inside the process's address space
+        int_ptr shared_memory; // Process address of shared memory
+        void *shared_mem_local; // local pointers to the shared memory
+        size_t shared_overhead; // Size of the overhead the shared memory has
+        size_t shared_size; // Total size of mapping
+
+        // Disable the implicit constructors
+        process_memory( const process_memory &rhs );
+        process_memory &operator=( const process_memory &rhs );
+    public:
+
+        process_memory() : memory(0), shared_memory(0), shared_mem_local(MAP_FAILED), shared_overhead(0), shared_size(0)
+        {
+        }
+
+        ~process_memory();
+        
+        void set_local_addr(void *addr, size_t size, size_t overhead)
+        {
+            assert(shared_mem_local==MAP_FAILED);
+            if( addr!=MAP_FAILED && addr!=NULL ) {
+                shared_mem_local=(void *)(((int_ptr)addr)+overhead);
+                shared_overhead=overhead;
+                shared_size=size;
+            }
+        }
+        void set_remote_static(int_ptr addr)
+        {
+            assert(memory==0);
+            memory=addr;
+        }
+        void set_remote_shared(int_ptr addr)
+        {
+            shared_memory=addr;
+        }
+
+        // Accessors
+        void *get_loc() const
+        {
+            return shared_mem_local!=MAP_FAILED ? shared_mem_local : NULL;
+        }
+        char *get_loc_c() const
+        {
+            return (char *)get_loc();
+        }
+
+        int_ptr get_mem() const
+        {
+            return memory;
+        }
+
+        int_ptr get_shared() const
+        {
+            return shared_memory;
+        }
+    };
+
+    ref_count<process_memory> mem;
 
     int_ptr context_state[NUM_SAVED_STATES];
     void *saved_state[PTLIB_STATE_SIZE];
@@ -87,7 +147,12 @@ struct pid_state {
     int trace_mode; // Which ptrace mode was used to run the process
     pid_t session_id;
 
-    std::string root;
+    ref_count<std::string> root;
+
+    // The credentials (including the Linux specific file system UID)
+    uid_t uid, euid, suid, fsuid;
+    gid_t gid, egid, sgid, fsgid;
+    std::set<gid_t> groups;
 
 // Values for trace_mode
 #define TRACE_DETACHED  0x0
@@ -107,6 +172,7 @@ struct pid_state {
         DEF_VAR( int, status)
         DEF_VAR( struct rusage, usage)
         DEF_VAR( bool, debugonly) // Whether a parent that is not a debugger would have got this message
+
     public:
         wait_state() : _pid(0), _status(0), _debugonly(true)
         {
@@ -120,9 +186,11 @@ struct pid_state {
 #undef DEF_VAR
     std::list<wait_state> waiting_signals;
 
-    pid_state() : state(INIT), memory(NULL), shared_memory(NULL), shared_mem_local(), debugger(0),
-        parent(0), num_children(0), num_debugees(0), trace_mode(TRACE_DETACHED), session_id(0), root("/")
+    pid_state() : state(INIT), mem(ref_count<process_memory>(new process_memory)), debugger(0),
+        parent(0), num_children(0), num_debugees(0), trace_mode(TRACE_DETACHED), session_id(0), root(),
+        uid(ROOT_UID), euid(ROOT_UID), suid(ROOT_UID), fsuid(ROOT_UID), gid(ROOT_GID), egid(ROOT_GID), sgid(ROOT_GID), fsgid(ROOT_GID)
     {
+        groups.insert(ROOT_GID);
     }
 };
 
@@ -151,4 +219,6 @@ bool allocate_process_mem( pid_t pid, pid_state *state, int sc_num );
 
 void dump_registers( pid_t pid );
 
+#define PROC_MEM_LOCK()
+
 #endif /* PARENT_H */
